=====
Usage
=====

To use kalyke in a project::

    >>> from kalyke.seaborn.styles import line
    >>> line.blue
    {'scatter_kws': {'color': 'cornflowerblue', 's': 200, 'alpha': 0.5}, 'line_kws': {'color': 'cornflowerblue', 'lw': 2}}

